// Copyright 2017 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

// Definitions for streaming encryption using AES-GCM
// with HKDF as key derivation function.
syntax = "proto3";

package google.crypto.tink;

import "proto/common.proto";

option java_package = "com.google.crypto.tink.proto";
option java_multiple_files = true;
option go_package = "github.com/google/tink/go/proto/aes_gcm_hkdf_streaming_go_proto";

message AesGcmHkdfStreamingParams {
  uint32 ciphertext_segment_size = 1;
  uint32 derived_key_size = 2;  // size of AES-GCM keys derived for each segment
  HashType hkdf_hash_type = 3;
}

message AesGcmHkdfStreamingKeyFormat {
  uint32 version = 3;
  AesGcmHkdfStreamingParams params = 1;
  uint32 key_size = 2;  // size of the main key (aka. "ikm", input key material)
}

// key_type: type.googleapis.com/google.crypto.tink.AesGcmHkdfStreamingKey
message AesGcmHkdfStreamingKey {
  uint32 version = 1;
  AesGcmHkdfStreamingParams params = 2;
  bytes key_value = 3;
}
